import * as React from 'react';
import {
  pie,
  arc,
  interpolateRgb,
  format,
  scaleOrdinal,
} from 'd3';
import { Slice } from './Slice';
import { Check } from './Check';
import { ColorLegend } from './ColorLegend';

const donThemes = [
  { cat: 'Health', pc: 0.323 },
  { cat: 'Support', pc: 0.252 },
  { cat: 'Education', pc: 0.1323 },
  { cat: 'Poverty reduction', pc: 0.108 },
  { cat: 'Other', pc: 0.185 },
];

const height = 500;
const width = 960;

const xValue = (d) => d.pc;
const colorValue = (d) => d.cat;
const colorRange = ['#eaaf79', '#bc3358'];

const donutWidth = 80;

const innerRadius = 110;
const outerRadius = innerRadius + donutWidth;
let colors = [];

 let interpolate = d3.interpolateRgb('#eaaf79', '#bc3358');

  donThemes.map((slice, index) => {
    colors.push(interpolate(index / (donThemes.length - 1)));
  });

export const SimplePieChart = () => {
  const xData = donThemes.map(xValue).sort();
  let pie = d3.pie()(xData);

  const colorScale = scaleOrdinal()
  	.domain(donThemes.map(colorValue))
  	.range(colors.reverse());
  
  console.log(colorScale.domain())
  console.log(colorScale.range())

  return (
    <svg height={height} width={width}>
      <g
        transform={`translate(${width / 4 + 20},${height / 2})`}
      >
        <Slice
          pie={pie}
          outerRadiusMain={outerRadius}
          innerRadiusMain={innerRadius}
          xValue={xData}
          donutWidth={donutWidth}
          colors={colors.reverse()}
        />
      </g>
      {/* <Check/> */}
      <g transform={`translate(${innerWidth / 2 + 70}, 60)`}>
      	<ColorLegend 
          colorScale={colorScale} 
          tickSpacing={50}
  				tickSize={40}
  				tickTextOffset={50}
        />
      </g>
    </svg>
  );
};
